@@ -39,11 +39,23 @@ class ReportGenerator():
             'storage_size_over',
             'repository_size',
             'repository_size_over',
+            'wiki_size',
+            "lfs_objects_size",
+            "lfs_objects_size_over",
+            "job_artifacts_size",
+            "job_artifacts_size_over",
+            "pipeline_artifacts_size",
+            "pipeline_artifacts_size_over",            
+            "snippets_size",
+            "snippets_size_over",
+            "uploads_size",
+            "uploads_size_over",
             'Tags',
             'Tags_over',
             'Package Types In Use',
             'Total Packages Size',
-            'Container Registry Size']
+            'Container Registry Size',
+            'Estimated Export Size']
         utils.write_to_csv(self.csv_file, self.csv_columns, [])
         utils.write_to_csv(self.rollup_file, self.csv_columns, [])
         with open("report.txt", "w") as f:
